==> zio-aws-textract_2.13-5.17.104.12-sources.jar: zio/aws/textract/model/IdentityDocumentField.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class IdentityDocumentField(
    `type`: Option[zio.aws.textract.model.AnalyzeIDDetections] = None,
    valueDetection: Option[zio.aws.textract.model.AnalyzeIDDetections] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.IdentityDocumentField = {
    import IdentityDocumentField.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.IdentityDocumentField
      .builder()
      .optionallyWith(`type`.map(value => value.buildAwsValue()))(_.`type`)
      .optionallyWith(valueDetection.map(value => value.buildAwsValue()))(
        _.valueDetection
      )
      .build()
  }
  def asReadOnly: zio.aws.textract.model.IdentityDocumentField.ReadOnly =
    zio.aws.textract.model.IdentityDocumentField.wrap(buildAwsValue())
}
object IdentityDocumentField {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.IdentityDocumentField
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.IdentityDocumentField =
      zio.aws.textract.model.IdentityDocumentField(
        `type`.map(value => value.asEditable),
        valueDetection.map(value => value.asEditable)
      )
    def `type`: Option[zio.aws.textract.model.AnalyzeIDDetections.ReadOnly]
    def valueDetection
        : Option[zio.aws.textract.model.AnalyzeIDDetections.ReadOnly]
    def getType: ZIO[
      Any,
      AwsError,
      zio.aws.textract.model.AnalyzeIDDetections.ReadOnly
    ] = AwsError.unwrapOptionField("type", `type`)
    def getValueDetection: ZIO[
      Any,
      AwsError,
      zio.aws.textract.model.AnalyzeIDDetections.ReadOnly
    ] = AwsError.unwrapOptionField("valueDetection", valueDetection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.IdentityDocumentField
  ) extends zio.aws.textract.model.IdentityDocumentField.ReadOnly {
    override val `type`
        : Option[zio.aws.textract.model.AnalyzeIDDetections.ReadOnly] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.textract.model.AnalyzeIDDetections.wrap(value))
    override val valueDetection
        : Option[zio.aws.textract.model.AnalyzeIDDetections.ReadOnly] = scala
      .Option(impl.valueDetection())
      .map(value => zio.aws.textract.model.AnalyzeIDDetections.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.IdentityDocumentField
  ): zio.aws.textract.model.IdentityDocumentField.ReadOnly = new Wrapper(impl)
}

==> zio-aws-textract_2.13-5.17.190.2-sources.jar: zio/aws/textract/model/IdentityDocumentField.scala <==
package zio.aws.textract.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class IdentityDocumentField(
    `type`: Optional[zio.aws.textract.model.AnalyzeIDDetections] =
      Optional.Absent,
    valueDetection: Optional[zio.aws.textract.model.AnalyzeIDDetections] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.textract.model.IdentityDocumentField = {
    import IdentityDocumentField.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.textract.model.IdentityDocumentField
      .builder()
      .optionallyWith(`type`.map(value => value.buildAwsValue()))(_.`type`)
      .optionallyWith(valueDetection.map(value => value.buildAwsValue()))(
        _.valueDetection
      )
      .build()
  }
  def asReadOnly: zio.aws.textract.model.IdentityDocumentField.ReadOnly =
    zio.aws.textract.model.IdentityDocumentField.wrap(buildAwsValue())
}
object IdentityDocumentField {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.textract.model.IdentityDocumentField
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.textract.model.IdentityDocumentField =
      zio.aws.textract.model.IdentityDocumentField(
        `type`.map(value => value.asEditable),
        valueDetection.map(value => value.asEditable)
      )
    def `type`: Optional[zio.aws.textract.model.AnalyzeIDDetections.ReadOnly]
    def valueDetection
        : Optional[zio.aws.textract.model.AnalyzeIDDetections.ReadOnly]
    def getType: ZIO[
      Any,
      AwsError,
      zio.aws.textract.model.AnalyzeIDDetections.ReadOnly
    ] = AwsError.unwrapOptionField("type", `type`)
    def getValueDetection: ZIO[
      Any,
      AwsError,
      zio.aws.textract.model.AnalyzeIDDetections.ReadOnly
    ] = AwsError.unwrapOptionField("valueDetection", valueDetection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.textract.model.IdentityDocumentField
  ) extends zio.aws.textract.model.IdentityDocumentField.ReadOnly {
    override val `type`
        : Optional[zio.aws.textract.model.AnalyzeIDDetections.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.textract.model.AnalyzeIDDetections.wrap(value))
    override val valueDetection
        : Optional[zio.aws.textract.model.AnalyzeIDDetections.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.valueDetection())
        .map(value => zio.aws.textract.model.AnalyzeIDDetections.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.textract.model.IdentityDocumentField
  ): zio.aws.textract.model.IdentityDocumentField.ReadOnly = new Wrapper(impl)
}
